Class: ActionController::Base
- Inherits:
-
Object
- Object
- ActionController::Base
- Defined in:
- lib/shway.rb
Overview
add the presenter helper and set it up in a before_filter a before
Direct Known Subclasses
Instance Method Summary collapse
-
#setup_shway_presenter ⇒ Object
this is being done here now so that local stylesheets can reference skin styles and values.
Instance Method Details
#setup_shway_presenter ⇒ Object
this is being done here now so that local stylesheets can reference skin styles and values. Shway.reload_styles
125 126 127 |
# File 'lib/shway.rb', line 125 def setup_shway_presenter @current_shway_presenter = ApplicationPresenter.new(self) end |